@@ -87,31 +87,3 @@ def app_template(app_name, deploy_paths, categories, app_attributes, model, driv
 
     return xml.format(AppResourceInfo=app_resource, Categories=categories if categories else "")
 
-
-dep1 = dict()
-dep1['name'] = 'dep1'
-dep1['service_name'] = 'service1'
-dep1_attrs = dict()
-dep1_attrs['attrib1'] = 'value1'
-dep1_attrs['attrib2'] = 'value2'
-dep1_attrs['attrib3'] = 'value3'
-dep1['attributes'] = dep1_attrs
-
-dep2 = dict()
-dep2['name'] = 'dep2'
-dep2['service_name'] = 'service2'
-dep2_attrs = dict()
-dep2_attrs['attrib21'] = 'value21'
-dep2_attrs['attrib22'] = 'value22'
-dep2_attrs['attrib23'] = 'value23'
-dep2['attributes'] = dep2_attrs
-
-deploy_paths = [dep1, dep2]
-
-app_attributes = dict()
-app_attributes['attr1'] = 'value1'
-app_attributes['attr2'] = 'value2'
-app_attributes['attr3'] = 'value3'
-
-print app_template('test app', deploy_paths, ['Applications'], app_attributes, 'testmodel', 'testdriver', 'cp1', 'testimage')
-#print deployment_paths(deploy_paths, 'cp1')
