@@ -1,7 +1,5 @@
 class DeployInfo(dict):
-    def __init__(self, deployment_paths, app_template_image=''):
-
-        display_image = app_template_image
+    def __init__(self, deployment_paths):
 
         deploypaths = []
         for deploy_path in deployment_paths:
@@ -13,4 +11,4 @@ class DeployInfo(dict):
             for attribute in deploy_path.DeploymentService.Attributes:
                 path['attributes'][attribute.Name] = attribute.Value
             deploypaths.append(path)
-        dict.__init__(self, deploypaths=deploypaths, display_image=display_image)
+        dict.__init__(self, deploypaths=deploypaths)
